@@ -1,5 +1,5 @@
 # -*- coding: utf-8 *-*
-"""Lets doit_ read tasks defined using classes, decorated functions or function
+"""Lets doit read tasks defined using classes, decorated functions or function
 calls."""
 
 class TaskBase(object):
